var App;

App = angular.module("app", ["ionic", "ngAdsense", "angular-google-analytics", "app.list", "app.movie", "app.reviews"]).run(function($ionicPlatform, adMob, CONFIG, Analytics) {
  var _ref;
  console.log('platform ->', CONFIG.platform);
  if ((_ref = CONFIG.platform) === 'firefox' || _ref === 'tizen') {
    ionic.Platform.setPlatform('android');
  }
  return $ionicPlatform.ready(function() {
    var _ref1;
    if ((_ref1 = window.StatusBar) != null) {
      _ref1.styleDefault();
    }
    adMob.hookListeners();
    adMob.banner();
    adMob.loadInterstitial();
    return typeof analytics !== "undefined" && analytics !== null ? analytics.startTrackerWithId('UA-42428351-6') : void 0;
  });
}).config(function($stateProvider, $urlRouterProvider, CONFIG, AnalyticsProvider) {
  var trackingCodes, _ref;
  $stateProvider.state("tabView", {
    abstract: true,
    templateUrl: "app/templates/tabView.html"
  });
  $urlRouterProvider.otherwise("/us");
  if ((_ref = CONFIG.platform) === 'firefox' || _ref === 'tizen') {
    trackingCodes = {
      firefox: 'UA-42148467-6',
      tizen: 'UA-42148467-7'
    };
    AnalyticsProvider.setAccount(trackingCodes[CONFIG.platform]);
    AnalyticsProvider.trackPages(true);
    AnalyticsProvider.trackUrlParams(true);
    return AnalyticsProvider.useAnalytics(true);
  }
});

App.directive('onPosterError', function() {
  return {
    link: function(scope, element, attrs) {
      return element.bind('error', function() {
        scope.movie.showPoster = false;
        return scope.$apply();
      });
    }
  };
});

App.directive('tmAdSense', [
  'CONFIG', function(CONFIG) {
    return {
      restrict: "E",
      templateUrl: function() {
        return "app/directives/templates/" + CONFIG.platform + "/tmAdSense.html";
      },
      scope: {},
      link: function($scope, element) {}
    };
  }
]);

App.filter('range', function() {
  return function(input, total) {
    var i, _i;
    total = parseInt(total);
    if (total) {
      for (i = _i = 1; 1 <= total ? _i <= total : _i >= total; i = 1 <= total ? ++_i : --_i) {
        input.push(i);
      }
      return input;
    } else {
      return [];
    }
  };
});

App.factory('adMob', [
  'CONFIG', '$rootScope', function(CONFIG, $rootScope) {
    var clear, isLoaded, loadInterstitial;
    isLoaded = false;
    loadInterstitial = function() {
      if (CONFIG.platform === 'android') {
        console.log('loading interstitial');
        return typeof admob !== "undefined" && admob !== null ? admob.requestInterstitialAd({
          interstitialAdId: "ca-app-pub-7839575520735973/9815858047",
          autoShowInterstitial: false
        }) : void 0;
      }
    };
    clear = function(err) {
      console.log('clear', err);
      isLoaded = false;
      return loadInterstitial();
    };
    $rootScope.$on('$stateChangeStart', function(event, toState, toParams, fromState, fromParams, options) {
      console.log(fromState, toState);
      if (CONFIG.platform === 'android' && isLoaded && fromState.name === 'tabView.us' && toState.name === 'tabView.movie-us') {
        console.log('showing interstitial');
        return typeof admob !== "undefined" && admob !== null ? admob.showInterstitialAd(clear, clear) : void 0;
      }
    });
    return {
      loadInterstitial: loadInterstitial,
      hookListeners: function() {
        if (CONFIG.platform === 'android') {
          document.addEventListener(typeof admob !== "undefined" && admob !== null ? admob.events.onAdLoaded : void 0, function() {
            console.log('interstitial loaded');
            return isLoaded = true;
          });
          return document.addEventListener(typeof admob !== "undefined" && admob !== null ? admob.events.onAdFailedToLoad : void 0, function(err) {
            console.log('interstitial failed to load');
            console.log(err);
            isLoaded = false;
            return loadInterstitial();
          });
        }
      },
      banner: function() {
        if (CONFIG.platform === 'android') {
          console.log('showing banner');
          if (typeof admob !== "undefined" && admob !== null) {
            admob.setOptions({
              publisherId: "ca-app-pub-7839575520735973/8339124845",
              autoShowInterstitial: false
            });
          }
          return typeof admob !== "undefined" && admob !== null ? admob.createBannerView() : void 0;
        }
      }
    };
  }
]);

App.factory('CountryCode', [
  function() {
    var countryCode;
    countryCode = null;
    return {
      get: function() {
        return countryCode;
      },
      set: function(code) {
        return countryCode = code;
      }
    };
  }
]);

App.factory('Movies', [
  '$http', '$q', function($http, $q) {
    var apiKey;
    apiKey = "api_key=e030e51468f4d3e923ecd51b68db5973";
    return {
      getAll: function() {
        return $http({
          url: 'https://api.themoviedb.org/3/movie/upcoming?page=1&' + apiKey,
          method: 'GET',
          timeout: 5000
        });
      },
      getOne: function(id) {
        return $http({
          url: 'https://api.themoviedb.org/3/movie/' + id + '?' + apiKey,
          method: 'GET',
          timeout: 5000
        });
      }
    };
  }
]);

var ListModule;

ListModule = angular.module("app.list", []).config(function($stateProvider) {
  return $stateProvider.state("tabView.us", {
    url: "/us",
    views: {
      "us-list": {
        templateUrl: "app/modules/List/templates/List.html",
        controller: "ListCtrl"
      }
    }
  });
});

var MovieModule;

MovieModule = angular.module("app.movie", []).config(function($stateProvider) {
  return $stateProvider.state("tabView.movie-us", {
    url: "/movie-us/{id}",
    views: {
      "us-list": {
        templateUrl: "app/modules/Movie/templates/Movie.html",
        controller: "MovieCtrl"
      }
    }
  }).state("tabView.movie-uk", {
    url: "/movie-uk/{title}",
    views: {
      "uk-list": {
        templateUrl: "app/modules/Movie/templates/Movie.html",
        controller: "MovieCtrl"
      }
    }
  });
});

var ReviewsModule;

ReviewsModule = angular.module("app.reviews", []).config(function($stateProvider) {
  return $stateProvider.state("tabView.reviews-us", {
    url: "/movie-us/{id}/reviews",
    params: {
      movieTitle: null
    },
    views: {
      "us-list": {
        templateUrl: "app/modules/Reviews/templates/Reviews.html",
        controller: "ReviewsCtrl"
      }
    }
  }).state("tabView.reviews-uk", {
    url: "/movie-uk/{id}/reviews",
    params: {
      movieTitle: null
    },
    views: {
      "uk-list": {
        templateUrl: "app/modules/Reviews/templates/Reviews.html",
        controller: "ReviewsCtrl"
      }
    }
  }).state("tabView.reviews-fr", {
    url: "/movie-fr/{id}/reviews",
    params: {
      movieTitle: null
    },
    views: {
      "fr-list": {
        templateUrl: "app/modules/Reviews/templates/Reviews.html",
        controller: "ReviewsCtrl"
      }
    }
  });
});

ListModule.controller("ListCtrl", [
  '$scope', 'Movies', 'CountryCode', '$state', '$ionicLoading', '$ionicPopup', 'CONFIG', 'Analytics', function($scope, Movies, CountryCode, $state, $ionicLoading, $ionicPopup, CONFIG, Analytics) {
    var _ref;
    $scope.countryCode = $state.$current.toString().split('.')[1];
    CountryCode.set($scope.countryCode);
    if (typeof analytics !== "undefined" && analytics !== null) {
      analytics.trackView('List ' + $scope.countryCode);
    }
    if ((_ref = CONFIG.platform) === 'firefox' || _ref === 'tizen') {
      Analytics.trackPage($scope.countryCode);
    }
    $ionicLoading.show({
      template: 'Loading...'
    });
    $scope.noMovies = false;
    return Movies.getAll().then(function(movies) {
      var _ref1;
      $scope.movies = movies.data.results;
      if (!$scope.movies || !((_ref1 = $scope.movies) != null ? _ref1.length : void 0)) {
        return $scope.noMovies = true;
      }
    })["catch"](function() {
      $scope.noMovies = true;
      return $ionicPopup.alert({
        title: 'Network error',
        template: 'Unable to get data...'
      });
    })["finally"](function() {
      return $ionicLoading.hide();
    });
  }
]);

MovieModule.controller("MovieCtrl", [
  '$scope', 'Movies', 'CountryCode', '$state', '$ionicLoading', '$ionicPopup', '$window', '$ionicHistory', 'CONFIG', 'Analytics', function($scope, Movies, CountryCode, $state, $ionicLoading, $ionicPopup, $window, $ionicHistory, CONFIG, Analytics) {
    $scope.countryCode = CountryCode.get();
    $scope.movie = {};
    $scope.isLoading = true;
    $ionicLoading.show({
      template: 'Loading...'
    });
    console.log('params', $state.params);
    Movies.getOne($state.params.id).then(function(movie) {
      $ionicLoading.hide();
      $scope.movie = movie.data;
      return $scope.isLoading = false;
    }, function() {
      $ionicLoading.hide();
      $scope.isLoading = false;
      return $ionicPopup.alert({
        title: 'Network error',
        template: 'Unable to get data...'
      });
    });
    $scope.goToList = function() {
      return $ionicHistory.goBack();
    };
    $scope.goToIMDB = function() {
      var url, _ref;
      if ($scope != null ? (_ref = $scope.movie) != null ? _ref.imdb_id : void 0 : void 0) {
        url = 'http://www.imdb.com/title/' + $scope.movie.imdb_id;
        if (CONFIG.platform === 'android') {
          cordova.InAppBrowser.open(url, '_blank', 'location=yes');
        } else {
          $window.open(url, '_blank', 'location=yes');
        }
      }
      return true;
    };
    return $scope.getArray = function(arr) {
      return arr.map(function(item) {
        return item.name;
      }).join(', ');
    };
  }
]);

ReviewsModule.controller("ReviewsCtrl", [
  '$scope', 'Movies', '$state', '$ionicLoading', '$ionicPopup', '$window', '$ionicHistory', 'CONFIG', 'Analytics', function($scope, Movies, $state, $ionicLoading, $ionicPopup, $window, $ionicHistory, CONFIG, Analytics) {
    var _ref;
    $scope.reviews = {};
    $ionicLoading.show({
      template: 'Loading...'
    });
    $scope.noReviews = false;
    $scope.movieTitle = $state.params.movieTitle;
    if ((_ref = CONFIG.platform) === 'firefox' || _ref === 'tizen') {
      Analytics.trackPage($scope.movieTitle + ' - reviews');
    }
    Movies.getReviews($state.params.id).then(function(reviews) {
      var review, _i, _len, _ref1, _ref2, _ref3, _ref4, _ref5;
      $ionicLoading.hide();
      $scope.movieReviews = [];
      _ref3 = (_ref1 = reviews.data) != null ? (_ref2 = _ref1.contents) != null ? _ref2.reviews : void 0 : void 0;
      for (_i = 0, _len = _ref3.length; _i < _len; _i++) {
        review = _ref3[_i];
        $scope.movieReviews.push({
          date: review.date,
          quote: review.quote,
          stars: $scope.getStars(review.original_score),
          linkToFullReview: (_ref4 = review.links) != null ? _ref4.review : void 0
        });
      }
      if (!$scope.movieReviews || !((_ref5 = $scope.movieReviews) != null ? _ref5.length : void 0)) {
        return $scope.noReviews = true;
      }
    }, function() {
      $ionicLoading.hide();
      return $ionicPopup.alert({
        title: 'Network error',
        template: 'Unable to get data...'
      });
    });
    $scope.goToFullReview = function(index) {
      var _ref1, _ref2;
      if ((_ref1 = $scope.movieReviews) != null ? _ref1[index].linkToFullReview : void 0) {
        $window.open((_ref2 = $scope.movieReviews) != null ? _ref2[index].linkToFullReview : void 0, '_blank', 'location=yes');
      }
      return true;
    };
    $scope.getStars = function(result) {
      var e, res, starsNumber;
      starsNumber = 0;
      if (result) {
        try {
          if (result.indexOf('/') > -1) {
            res = result.split("/");
            starsNumber = Math.floor(res[0] / res[1] * 5);
          } else {
            switch (result) {
              case "A":
              case "A-":
                starsNumber = 5;
                break;
              case "B+":
              case "B":
              case "B-":
                starsNumber = 4;
                break;
              case "C+":
              case "C":
              case "C-":
                starsNumber = 3;
                break;
              case "D+":
              case "D":
              case "D-":
                starsNumber = 2;
                break;
              case "E+":
              case "E":
              case "E-":
                starsNumber = 1;
                break;
              default:
                starsNumber = 0;
            }
          }
        } catch (_error) {
          e = _error;
          console.warn('Unable to normalize rating');
        }
      }
      return starsNumber;
    };
    return $scope.goToMovieDetails = function() {
      return $ionicHistory.goBack();
    };
  }
]);

App.constant('CONFIG', {
  platform: 'android'
});
